@@ -13,12 +13,12 @@ class Banks(ListoAPI):
 
     def upload_bank_files(self, filename, file_stream, bank=None, account_number=None, currency=None, rfc_id=None):
         return self.make_request(method="POST", path="/banks/upload_bank_files",
-                                 files={'file': file_stream, filename: {
+                                 files={'file': file_stream},
+                                 data={filename: {
                                     "bank": bank,
                                     "account_number": account_number,
                                     "currency": currency,
-                                    "rfc_id": rfc_id}
-                                }).json()['status']
+                                    "rfc_id": rfc_id}}).json()['status']
 
     def get_bank_transactions(self, **kwargs):
         return self.make_request(method="GET", path="/banks/bank_transaction", params=kwargs) \
